@@ -147,9 +147,7 @@ def random_date(
     return choose(dates.date_range(base, dir, unit, num))
 
 
-def random_time(
-    **kwargs,
-) -> str:
+def random_time(**kwargs,) -> str:
     """
     Generate a random date.
     :param base: The base date to generate a range to select from.
